Struct simple_error::SimpleError [−][src]
pub struct SimpleError { /* fields omitted */ }A type that represents a simple error.
This type uses a String to store the error string, and it implements std::error::Error.
Methods
impl SimpleError[src]
impl SimpleErrorpub fn new<T: Into<String>>(t: T) -> SimpleError[src]
pub fn new<T: Into<String>>(t: T) -> SimpleErrorCreates a new simple error.
This function can take any type that implements Into<String>.
Examples
use self::simple_error::SimpleError; // errors can be created from `str` let err = SimpleError::new("an error from str"); // errors can also be created from `String` let err = SimpleError::new(String::from("an error from String"));
pub fn from<T: Error>(t: T) -> SimpleError[src]
pub fn from<T: Error>(t: T) -> SimpleErrorCreates a new simple error from another error.
This function can take any type that implements std::error::Error.
The error string will be the Display of the std::error::Error.
Examples
use self::simple_error::SimpleError; use std::io; // errors can be created from `io::Error` let err = SimpleError::from(io::Error::new(io::ErrorKind::Other, "oh no")); assert_eq!("oh no", format!("{}", err));
pub fn with<T: Error>(s: &str, t: T) -> SimpleError[src]
pub fn with<T: Error>(s: &str, t: T) -> SimpleErrorCreates a new simple error from a string with another error.
This function takes a string as error and a type that implements std::error::Error as
reason.
The error string will be the Display of the std::error::Error prefixed with the string
and ", ".
Examples
use self::simple_error::SimpleError; let err = SimpleError::with("cannot turn on tv", SimpleError::new("remote not found")); assert_eq!("cannot turn on tv, remote not found", format!("{}", err));
pub fn as_str(&self) -> &str[src]
pub fn as_str(&self) -> &strExtracts a string slice describing the error.
Examples
use self::simple_error::SimpleError; let s = SimpleError::new("critical error"); assert_eq!("critical error", s.as_str());